# meteo_swiss

Find the nearest MeteoSwiss automatic weather station for a given location and sensor type.

See {doc}`../examples/meteo_swiss` for usage examples.

## API Reference

```{eval-rst}
.. automodule:: pyedautils.meteo_swiss
   :members:
   :undoc-members:
   :show-inheritance:
```
